#
# spec file for package stlink
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           stlink
Version:        1.5.0
Release:        lp151.12.4
Summary:        STM32 discovery line linux programmer
License:        BSD-3-Clause
Group:          Development/Tools/Debuggers
Url:            https://github.com/texane/stlink
Source0:        https://github.com/texane/stlink/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-deprecated-libusb-function.patch
Patch0:         https://github.com/texane/stlink/commit/aaf8e9207581.patch#/fix-deprecated-libusb-function.patch
BuildRequires:  cmake
BuildRequires:  gtk3-devel
BuildRequires:  pkg-config
BuildRequires:  systemd-rpm-macros
BuildRequires:  udev
BuildRequires:  pkgconfig(libusb-1.0)
Requires:       udev
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%package        gui
Summary:        GUI for STM32 discovery line linux programmer
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}

%description    gui
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%package -n     libstlink-shared1
Summary:        Shared library for stlink
Group:          Development/Tools/Debuggers

%description -n libstlink-shared1
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%package        devel
Summary:        Development files for stlink package
#Requires:      %%{name} = %%{version}
Group:          Development/Tools/Debuggers
Requires:       libstlink-shared1 = %{version}

%description    devel
STLINK v1/v2 JTAG/SWD debugging/flashing tool for STM32 microcontrollers.

%prep
%setup -q
%patch0 -p1

%build
%cmake -DSTLINK_UDEV_RULES_DIR="%_udevrulesdir" \
       -DCMAKE_EXE_LINKER_FLAGS="-pie"

make %{?_smp_mflags}

%install
%cmake_install
# remove static lib sdi
rm -f %{buildroot}%{_libdir}/*.a
install -d %{buildroot}/%{_udevrulesdir}/
install -D -m 0644 etc/udev/rules.d/49-stlink*.rules %{buildroot}/%{_udevrulesdir}/

%post -n libstlink-shared1 -p /sbin/ldconfig

%postun -n libstlink-shared1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc LICENSE README.md doc/app-example doc/tested-boards.md doc/tutorial.md
%{_bindir}/st-*
%{_udevrulesdir}/49-stlink*
%config %{_sysconfdir}/modprobe.d/stlink_v1.conf
%{_mandir}/man1/st-flash.1*
%{_mandir}/man1/st-info.1*
%{_mandir}/man1/st-util.1*

%files -n libstlink-shared1
%{_libdir}/libstlink-shared.so.1*

%files gui
%defattr(-,root,root)
%{_bindir}/stlink-gui
%{_datadir}/stlink/

%files devel
%dir %{_includedir}/stlink
%{_includedir}/stlink.h
%{_includedir}/stlink/backend.h
%{_includedir}/stlink/chipid.h
%{_includedir}/stlink/commands.h
%{_includedir}/stlink/flash_loader.h
%{_includedir}/stlink/logging.h
%{_includedir}/stlink/mmap.h
%{_includedir}/stlink/reg.h
%{_includedir}/stlink/sg.h
%{_includedir}/stlink/usb.h
%{_includedir}/stlink/version.h
%{_libdir}/libstlink-shared.so
%{_libdir}/pkgconfig/stlink.pc

%changelog
* Tue May  8 2018 stefan.bruens@rwth-aachen.de
- update to release 1.5.0
  * Chip support added for:
    + STM32F72xx73xx support (#1969148)
    + Add support of STM32L496xx/4A6xx devices (#615)
  * Fixes:
    + Fix memory map for stm32l496xx boards (#639)
    + Fix write for microcontroler with RAM size less or equal to 32K (#637)
    + Added LIB_INSTALL_DIR to correct libs install on 64-bit systems (#636)
    + Fix verification of flash error for STM32L496x device (#618)
    + Fix build on Fedora with GCC 8 (#666)
- Fix failing build due to use of deprecated libusb function:
  Add fix-deprecated-libusb-function.patch
* Tue Nov 28 2017 boris@steki.net
- update to release 1.4.0
  * Add support for STM32L452 target
  * Initial support to compile with Microsoft Visual Studio 2017
  * Added support for flashing second bank on STM32F10x_XL
  * Add support for STM32L011 target
  * Allow building of debian package with CPack
  * Add preliminary support for STM32L011 to see it after probe
  * Strip full paths to source files in log
  * Add support for STM32F413 target
  * Add support for Semihosting SYS_READC
  * Deprecation of autotools (autoconf, automake)
  * Removal of undocumented st-term utility,
    which is now replaced by st-util ARM semihosting feature
  * Add support for native debian packaging
  * Add intel hex file reading for st-flash
  * Add --reset command to st-flash
  * Support serial numbers argument for st-util
    and st-flash for multi-programmer setups
  * Add kill ('k') command to gdb-server for st-util
  * Add manpages (generated with pandoc from Markdown)
  * Rewrite commandline parsing for st-flash
  * Add support for ARM semihosting to st-util
  * Chip support added for:
    + STM32L432
    + STM32F412
    + STM32F410
    + Add memory map for STM32F401XE
    + L0x Category 5 devices
    + Add L0 Category 2 device
* Sun May  8 2016 dmitry_r@opensuse.org
- Update to version 1.2.0
  * Add multiple stlink probing (`st-info --probe`, `st-info --hla-serial`)
    with printing serial in hex and OpenOCD `hla_serial` format
  * Add stlink usb probe API functions
  * Added parameter to specify one stlink v2 of many
  * Chip support added for: STM32L053R8, STM32F7, STM32L4, F446,
    STM32F303 High Density, STM32L1xx Cat.2 devices
  * Board support added for: Nucleo-F303RE, Nucleo-F411RE
  * Minor fixes and updates
* Fri Apr  3 2015 dmitry_r@opensuse.org
- Update to version 1.1.0
  * New devices support, see included README file
  * Bugfixes
* Wed Jun 11 2014 dmitry_r@opensuse.org
- Add COPYING and README to package documentation
* Fri Jun  6 2014 dmitry_r@opensuse.org
- Initial package, version 1.0.0
